.embed_video-chooser .chosen:before,
.embed_video-chooser .unchosen:before {
    display: none;
}
.embed_video-chooser .chosen {
    padding-left: 130px;
}
.embed_video-chooser .chosen:before {
    display: inline-block;
}
.embed_video-chooser .chosen .preview-embedvideo {
    float: left;
    margin-left: -130px;
    margin-right: 1em;
    max-width: 130px
}
.embed_video-chooser .chosen .preview-embedvideo img {
    max-width: 130px;
    max-height: 130px;
    height: auto;
    width: auto
}
