{% extends 'wagtailadmin/bulk_actions/confirmation/base.html' %}
{% load i18n %}
{% load wagtailadmin_tags %}
{% block titletag %}{% blocktrans count counter=items|length %}Add 1 embed video to new collection {% plural %}Add {{ counter }} embed videos to new collection{% endblocktrans %}{% endblock %}

{% block header %}
    {% trans "Add embed videos to collection" as add_str %}
    {% include "wagtailadmin/shared/header.html" with title=add_str icon="doc-full-inverse" %}
{% endblock header %}

{% block items_with_access %}
{% if items %}
    <p>
        {% blocktrans trimmed count counter=items|length %}
        Are you sure you want to add the following embed video to the selected collection?
        {% plural %}
        Are you sure you want to add the following embed videos to the selected collection?
        {% endblocktrans %}
    </p>
    <ul>
        {% for video in items %}
        <li>
            <a href="{% url 'wagtail_embed_videos:edit' video.item.id %}"  target="_blank" rel="noopener noreferrer">{{video.item.title}}</a>
        </li>
        {% endfor %}
    </ul>
{% endif %}
{% endblock items_with_access %}

{% block items_with_no_access %}

{% blocktrans asvar no_access_msg count counter=items_with_no_access|length %}You don't have permission to add this embed video to a collection{% plural %}You don't have permission to add these embed videos to a collection{% endblocktrans %}
{% include 'wagtail_embed_videos/bulk_actions/list_items_with_no_access.html' with items=items_with_no_access no_access_msg=no_access_msg %}

{% endblock items_with_no_access %}

{% block form_section %}
    {% if items %}
        {% trans 'Yes, add' as action_button_text %}
        {% trans "No, don't add" as no_action_button_text %}
        {% include 'wagtailadmin/bulk_actions/confirmation/form_with_fields.html' %}
    {% else %}
        {% include 'wagtailadmin/bulk_actions/confirmation/go_back.html' %}
    {% endif %}
{% endblock form_section %}
