{% extends 'wagtailadmin/bulk_actions/confirmation/list_items_with_no_access.html' %}
{% load i18n %}

{% block per_item %}
{% if item.can_edit %}
    <a href="{% url 'wagtail_embed_videos:edit' item.item.id %}" target="_blank" rel="noopener noreferrer">{{ item.item.title }}</a>
{% else %}
    {{ item.item.title }}
{% endif %}
{% endblock per_item %}
