# Generated by Django 2.2.24 on 2021-11-04 05:57

import django.db.models.deletion
import taggit.managers
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtail_embed_videos", "0005_auto_20211103_0802"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="embedvideo",
            options={"verbose_name": "embed video", "verbose_name_plural": "embed videos"},
        ),
        migrations.AlterField(
            model_name="embedvideo",
            name="created_at",
            field=models.DateTimeField(auto_now_add=True, db_index=True, verbose_name="created at"),
        ),
        migrations.AlterField(
            model_name="embedvideo",
            name="tags",
            field=taggit.managers.TaggableManager(
                blank=True, help_text=None, through="taggit.TaggedItem", to="taggit.Tag", verbose_name="tags"
            ),
        ),
        migrations.AlterField(
            model_name="embedvideo",
            name="thumbnail",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="wagtailimages.Image",
                verbose_name="thumbnail",
            ),
        ),
        migrations.AlterField(
            model_name="embedvideo",
            name="title",
            field=models.CharField(max_length=255, verbose_name="title"),
        ),
        migrations.AlterField(
            model_name="embedvideo",
            name="uploaded_by_user",
            field=models.ForeignKey(
                blank=True,
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to=settings.AUTH_USER_MODEL,
                verbose_name="uploaded by user",
            ),
        ),
    ]
