from django.apps import AppConfig


class WagtailEmbedVideosAppConfig(AppConfig):
    name = "wagtail_embed_videos"
    label = "wagtail_embed_videos"
    verbose_name = "Wagtail embed videos"
    default_auto_field = "django.db.models.AutoField"
